@@ -53,6 +53,14 @@ extern "C" {
     int n = INTEGER(n_r)[0];
     int m = INTEGER(m_r)[0];
     int nLTr = m*(m-1)/2+m;
+    int q = INTEGER(q_r)[0];
+    int nn = n*n;
+    int mm = m*m;
+    int nm = n*m;
+    int nq = n*q;
+    int qq = q*q;
+    int qm = q*m;
+    int qmqm = qm*qm;
 
     double *coordsD = REAL(coordsD_r);
 
@@ -62,7 +70,6 @@ extern "C" {
     //if predictive process
     bool isModPp = static_cast<bool>(INTEGER(isModPp_r)[0]);
 
-    int q = INTEGER(q_r)[0];
     double *knotsD = REAL(knotsD_r);
     double *coordsKnotsD = REAL(coordsKnotsD_r);
 
@@ -109,6 +116,8 @@ extern "C" {
     int verbose = INTEGER(verbose_r)[0];
     int nReport = INTEGER(nReport_r)[0];
 
+    double *A = (double *) R_alloc(mm, sizeof(double));
+    double *L = (double *) R_alloc(mm, sizeof(double));
 
     if(verbose){
       Rprintf("----------------------------------------\n");
@@ -180,15 +189,17 @@ extern "C" {
       }
 
       Rprintf("Metropolis starting values:\n");
-  
-      Rprintf("\tA starting:\n");
-      Rprintf("\t"); printVec(AStarting, nLTr);
-      Rprintf("\n"); 
+      
+      covExpand(AStarting, A, m);
+      Rprintf("\tA starting\n");
+      printMtrx(A, m, m);
+      Rprintf("\n");
 
       if(nugget){
-	Rprintf("\tL starting:\n");
-	Rprintf("\t"); printVec(LStarting, nLTr);
-	Rprintf("\n"); 
+	covExpand(LStarting, L, m);
+	Rprintf("\tL starting\n");
+	printMtrx(L, m, m);
+	Rprintf("\n");
       }
 
       Rprintf("\tphi starting\n");
@@ -228,14 +239,6 @@ extern "C" {
     /*****************************************
          Set-up MCMC sample matrices etc.
     *****************************************/
-    int nn = n*n;
-    int mm = m*m;
-    int nm = n*m;
-    int nq = n*q;
-    int qq = q*q;
-    int qm = q*m;
-    int qmqm = qm*qm;
-
     //spatial parameters
     int nSpParams, AIndx, LIndx, phiIndx, nuIndx;
 
@@ -342,9 +345,7 @@ extern "C" {
     double *tmp_qmqm1 = (double *) R_alloc(qm*qm, sizeof(double));
 
     double *candSpParams = (double *) R_alloc(nSpParams, sizeof(double));
-    double *A = (double *) R_alloc(mm, sizeof(double));
     double *K = (double *) R_alloc(mm, sizeof(double));
-    double *L = (double *) R_alloc(mm, sizeof(double));
     double *Psi = (double *) R_alloc(mm, sizeof(double)); 
     double *theta = (double *) R_alloc(mm, sizeof(double));
     double logMHRatio;
